### Name: Cuminc
### Title: Calculate nonparametric cumulative incidence functions and
###   associated standard errors
### Aliases: Cuminc
### Keywords: survival

### ** Examples

### These data were used in Putter, Fiocco & Geskus (2007)
data(aidssi)
ci <- Cuminc(time=aidssi$time, status=aidssi$status)
head(ci); tail(ci)
ci <- Cuminc(time="time", status="status", data=aidssi, group="ccr5")
head(ci); tail(ci)

### Some fake data
fake <- data.frame(surv=c(seq(2,10,by=2),seq(1,13,by=3),seq(1,9,by=2),seq(1,13,by=3)),
                    stat=rep(0:3,5),Tstage=c(1:4,rep(1:4,rep(4,4))))
fake$stat[fake$stat==0 & fake$Tstage==2] <- 3
fake$stat[fake$stat==3 & fake$Tstage==1] <- 2
fake
Cuminc(time="surv", status="stat", data=fake)
# If we remove all entries with status=0,
# we should get binomial sample probabilities and corresponding SEs
fake0 <- fake[fake$stat!=0,]
Cuminc(time="surv", status="stat", data=fake0)
# Use failcodes
Cuminc(time="surv", status="stat", data=fake, failcodes=c(1,3))
# Make grouping variable and status variable a factor
fake$Tstage <- factor(fake$Tstage,labels=c("T1","T2","T3","T4"))
fake$stat <- factor(fake$stat,levels=0:3,
            labels=c("eventfree","event1","event2","event3"))
Cuminc(time="surv", status="stat", data=fake, group="Tstage")
# (The warnings are a result of the fact that some failure causes
# do not occur for some values/levels of the grouping variable)
# The previous command didn't do what we wanted because we didn't
# tell Cuminc that eventfree is not an event
Cuminc(time="surv", status="stat", data=fake, group="Tstage",
        failcodes=c("event1","event2","event3"))



