### Name: redrank
### Title: Reduced rank proportional hazards model for competing risks and
###   multi-state models
### Aliases: redrank
### Keywords: survival

### ** Examples

# Based on Fiocco, Putter & van Houwelingen (2005)
data(ebmt2)
# transition matrix for competing risks
tmat <- trans.comprisk(6,names=c("Relapse","GvHD","Bacterial","Viral","Fungal","Other"))
# preparing long dataset
ebmt2$stat1 <- as.numeric(ebmt2$status==1)
ebmt2$stat2 <- as.numeric(ebmt2$status==2)
ebmt2$stat3 <- as.numeric(ebmt2$status==3)
ebmt2$stat4 <- as.numeric(ebmt2$status==4)
ebmt2$stat5 <- as.numeric(ebmt2$status==5)
ebmt2$stat6 <- as.numeric(ebmt2$status==6)
covs <- c("dissub","match","tcd","year","age")
ebmtlong <- msprep(time=c(NA,rep("time",6)),
            stat=c(NA,paste("stat",1:6,sep="")),
            data=ebmt2,keep=covs,trans=tmat)
# Get model matrix
cx <- coxph(Surv(Tstart,Tstop,status) ~
        dissub+match+tcd+year+age, data=ebmtlong, method="breslow")
mm <- model.matrix(cx)[,-1] # without intercept
mm <- data.frame(mm)
ebmtlong <- cbind(ebmtlong,mm)
# Somehow, cbind makes ebmtlong lose its "trans" attribute and "msdata" class
attr(ebmtlong, "trans") <- tmat
class(ebmtlong) <- c("msdata","data.frame")
covs <- names(mm)

# Actually run for a subset of the actual data
ebmtlongsub <- ebmtlong[1:1200,] # first 200 patients
# The reduced rank 2 solution
rr2 <- redrank(data=ebmtlongsub, covariates=covs, R=2, eps=0.001)
rr2$Alpha; rr2$Gamma; rr2$Beta; rr2$loglik

# This reproduces the results in Fiocco, Putter & van Houwelingen (2005)
# Takes a while to run
## Not run: 
##D     # The reduced rank 3 solution
##D     rr3 <- redrank(data=ebmtlong, covariates=covs, R=3)
##D     rr3$Alpha; rr3$Gamma; rr3$Beta; rr3$loglik
##D     # The full rank solution
##D     fullrank <- redrank(data=ebmtlong, covariates=covs, R=6)
##D     fullrank$Beta; fullrank$loglik
## End(Not run)



